<?php
/*
Plugin Name: ExXmlRpc for WordPressPost
Version: 0.2.1.0
Plugin URI:http://wpp.nethmk.com/plugin/ExXmlRpcForWPP/ExXmlRpc.zip
Description:ExXmlRpc(WordPressPost) is a plugin to post to WordPress from WordPressPost.
Author: nethmk
Author URI: http://wp.nethmk.com
*/

define("THIS_VERSION",     "0.2.1.0");


add_filter('is_protected_meta', 'my_is_protected_meta_filter', 10, 2);
function my_is_protected_meta_filter( $meta_key, $meta_type = null ) {
    if ($meta_key == '_thumbnail_id') {
        $protected=false;
    } else {
        $protected = (  '_' == $meta_key[0] );
    }
}

include_once(ABSPATH . WPINC . '/class-IXR.php');
include_once(ABSPATH . WPINC . '/class-wp-xmlrpc-server.php');

function wpex_xmlrpc_server($class_name) {
    return 'wpex_xmlrpc_server';
}

add_filter('wp_xmlrpc_server_class', 'wpex_xmlrpc_server');

class wpex_xmlrpc_server extends wp_xmlrpc_server {
    function __construct() {
        parent::__construct();
        $this->methods['wpex.getCurrentVersion'] = 'this:wpex_getCurrentVersion';
        $this->methods['wpex.getRecentPosts'] = 'this:wpex_getRecentPosts';
        $this->methods['wpex.getRecentPostTitles'] = 'this:wpex_getRecentPostTitles';
        $this->methods['wpex.newMediaObject'] = 'this:wpex_newMediaObject';
        $this->methods['wpex.getMediaItem'] = 'this:wpex_getMediaItem';
        $this->methods['wpex.getMediaLibrary'] = 'this:wpex_getMediaLibrary';
        $this->methods['wpex.findMediaLibrary'] = 'this:wpex_findMediaLibrary';
        $this->methods['wpex.findRecentPostTitles'] = 'this:wpex_findRecentPostTitles';
        $this->methods['wpex.replaceString'] = 'this:wpex_replaceString';
        $this->methods['wpex.getPages'] = 'this:wpex_getPages';
        $this->methods['wpex.saveCustomFields'] = 'this:wpxe_save_custom_fields';
    }

/* ------------------------------------------------------------------------- */
/* Check Version
/* ------------------------------------------------------------------------- */
	function wpex_getCurrentVersion($args) {
		return THIS_VERSION;
	}


/* ------------------------------------------------------------------------- */

	function wpex_getRecentPosts($args) {

		$this->escape($args);

		$blog_ID     = (int) $args[0];
		$username  = $args[1];
		$password   = $args[2];
		if ( isset( $args[3] ) )
			$query = array( 'numberposts' => absint( $args[3] ) );
		else
			$query = array();

		if ( !$user = $this->login($username, $password) )
			return $this->error;

		do_action('xmlrpc_call', 'metaWeblog.getRecentPosts');

		$posts_list = wp_get_recent_posts( $query );

		if ( !$posts_list )
			return array( );

		foreach ($posts_list as $entry) {
			if ( !current_user_can( 'edit_post', $entry['ID'] ) )
				continue;

			$post_date = mysql2date('Ymd\TH:i:s', $entry['post_date'], false);
			$post_date_gmt = mysql2date('Ymd\TH:i:s', $entry['post_date_gmt'], false);

			// For drafts use the GMT version of the date
			if ( $entry['post_status'] == 'draft' )
				$post_date_gmt = get_gmt_from_date( mysql2date( 'Y-m-d H:i:s', $entry['post_date'] ), 'Ymd\TH:i:s' );

			$categories = array();
			$catids = wp_get_post_categories($entry['ID']);
			foreach( $catids as $catid )
				$categories[] = get_cat_name($catid);

			$tagnames = array();
			$tags = wp_get_post_tags( $entry['ID'] );
			if ( !empty( $tags ) ) {
				foreach ( $tags as $tag ) {
					$tagnames[] = $tag->name;
				}
				$tagnames = implode( ', ', $tagnames );
			} else {
				$tagnames = '';
			}

			$post = get_extended($entry['post_content']);
			$link = post_permalink($entry['ID']);

			// Get the post author info.
			$author = get_userdata($entry['post_author']);

			$allow_comments = ('open' == $entry['comment_status']) ? 1 : 0;
			$allow_pings = ('open' == $entry['ping_status']) ? 1 : 0;

			// Consider future posts as published
			if ( $entry['post_status'] === 'future' )
				$entry['post_status'] = 'publish';

			// Get post format
			$post_format = get_post_format( $entry['ID'] );
			if ( empty( $post_format ) )
				$post_format = 'standard';

			// Get comment count this post
			do_action('xmlrpc_call', 'wp.getCommentCount');
			$count = wp_count_comments( (int) $entry['ID'] );

			$struct[] = array(
				'dateCreated' => new IXR_Date($post_date),
				'userid' => $entry['post_author'],
				'postid' => (string) $entry['ID'],
				'description' => $post['main'],
				'title' => $entry['post_title'],
				'link' => $link,
				'permaLink' => $link,
				// commented out because no other tool seems to use this
				// 'content' => $entry['post_content'],
				'categories' => $categories,
				'mt_excerpt' => $entry['post_excerpt'],
				'mt_text_more' => $post['extended'],
				'mt_allow_comments' => $allow_comments,
				'mt_allow_pings' => $allow_pings,
				'mt_keywords' => $tagnames,
				'wp_slug' => $entry['post_name'],
				'wp_password' => $entry['post_password'],
				'wp_author_id' => (string) $author->ID,
				'wp_author_display_name' => $author->display_name,
				'date_created_gmt' => new IXR_Date($post_date_gmt),
				'post_status' => $entry['post_status'],
				'custom_fields' => $this->get_custom_fields($entry['ID']),
				'wp_post_format' => $post_format,
				'wpex_total_comments' => $count->total_comments
			);

		}

		$recent_posts = array();
		for ( $j=0; $j<count($struct); $j++ ) {
			array_push($recent_posts, $struct[$j]);
		}

		return $recent_posts;
	}

	
/* ------------------------------------------------------------------------- */
	function wpex_getRecentPostTitles($args) {

		$this->escape($args);

		$blog_ID     = (int) $args[0];
		$username  = $args[1];
		$password   = $args[2];
		if ( isset( $args[3] ) )
			$query = array( 'numberposts' => absint( $args[3] ) );
		else
			$query = array();

		if ( !$user = $this->login($username, $password) )
			return $this->error;

		do_action('xmlrpc_call', 'mt.getRecentPostTitles');

		$posts_list = wp_get_recent_posts( $query );

		if ( !$posts_list ) {
			$this->error = new IXR_Error(500, __('Either there are no posts, or something went wrong.'));
			return $this->error;
		}

		foreach ($posts_list as $entry) {
			if ( !current_user_can( 'edit_post', $entry['ID'] ) )
				continue;

			$post_date = mysql2date('Ymd\TH:i:s', $entry['post_date'], false);
			$post_date_gmt = mysql2date('Ymd\TH:i:s', $entry['post_date_gmt'], false);

			// For drafts use the GMT version of the date
			if ( $entry['post_status'] == 'draft' )
				$post_date_gmt = get_gmt_from_date( mysql2date( 'Y-m-d H:i:s', $entry['post_date'] ), 'Ymd\TH:i:s' );

			// Get comment count this post
			do_action('xmlrpc_call', 'wp.getCommentCount');
			$count = wp_count_comments( (int) $entry['ID'] );
			
			$struct[] = array(
				'dateCreated' => new IXR_Date($post_date),
				'userid' => $entry['post_author'],
				'postid' => (string) $entry['ID'],
				'title' => $entry['post_title'],
				'post_status' => $entry['post_status'],
				'date_created_gmt' => new IXR_Date($post_date_gmt),
				'wpex_total_comments' => $count->total_comments
			);

		}

		$recent_posts = array();
		for ( $j=0; $j<count($struct); $j++ ) {
			array_push($recent_posts, $struct[$j]);
		}

		return $recent_posts;
	}
	
	
/* ------------------------------------------------------------------------- */
    function wpex_newMediaObject($args) {
        global $wpdb;

        $blog_ID     = (int) $args[0];
        $username  = $wpdb->escape($args[1]);
        $password   = $wpdb->escape($args[2]);
        $data        = $args[3];

        $name = sanitize_file_name( $data['name'] );
        $type = $data['type'];
        $bits = $data['bits'];

        logIO('O', '(MW) Received '.strlen($bits).' bytes');

        if ( !$user = $this->login($username, $password) )
            return $this->error;

        do_action('xmlrpc_call', 'metaWeblog.newMediaObject');

        if ( !current_user_can('upload_files') ) {
            logIO('O', '(MW) User does not have upload_files capability');
            $this->error = new IXR_Error(401, __('You are not allowed to upload files to this site.'));
            return $this->error;
        }

        if ( $upload_err = apply_filters( 'pre_upload_error', false ) )
            return new IXR_Error(500, $upload_err);

        if ( !empty($data['overwrite']) && ($data['overwrite'] == true) ) {
            // Get postmeta info on the object.
            $old_file = $wpdb->get_row("
                SELECT ID
                FROM {$wpdb->posts}
                WHERE post_title = '{$name}'
                    AND post_type = 'attachment'
            ");

            // Delete previous file.
            wp_delete_attachment($old_file->ID);

            // Make sure the new name is different by pre-pending the
            // previous post id.
            $filename = preg_replace('/^wpid\d+-/', '', $name);
            $name = "wpid{$old_file->ID}-{$filename}";
        }

        $upload = wp_upload_bits($name, NULL, $bits);
        if ( ! empty($upload['error']) ) {
            $errorString = sprintf(__('Could not write file %1$s (%2$s)'), $name, $upload['error']);
            logIO('O', '(MW) ' . $errorString);
            return new IXR_Error(500, $errorString);
        }
        // Construct the attachment array
        // attach to post_id 0
        $post_id = 0;
        $attachment = array(
            'post_title' => $name,
            'post_content' => '',
            'post_type' => 'attachment',
            'post_parent' => $post_id,
            'post_mime_type' => $type,
            'guid' => $upload[ 'url' ]
        );

        // Save the data
        $id = wp_insert_attachment( $attachment, $upload[ 'file' ], $post_id );
        wp_update_attachment_metadata( $id, wp_generate_attachment_metadata( $id, $upload['file'] ) );

        return apply_filters( 'wp_handle_upload', array( 'file' => $name, 'url' => $upload[ 'url' ], 'type' => $type, 'id' => $id ), 'upload' );
    }

/* ------------------------------------------------------------------------- */
	function wpex_getMediaItem($args) {
		$this->escape($args);

		$blog_id		= (int) $args[0];
		$username		= $args[1];
		$password		= $args[2];
		$attachment_id	= (int) $args[3];

		if ( !$user = $this->login($username, $password) )
			return $this->error;

		if ( !current_user_can( 'upload_files' ) )
			return new IXR_Error( 403, __( 'You can not get MediaItem' ) );

		do_action('xmlrpc_call', 'wp.getMediaItem');

		if ( ! $attachment = get_post($attachment_id) )
			return new IXR_Error( 404, __( 'Invalid attachment ID.' ) );

		// Format page date.
		$attachment_date = mysql2date('Ymd\TH:i:s', $attachment->post_date, false);
		$attachment_date_gmt = mysql2date('Ymd\TH:i:s', $attachment->post_date_gmt, false);

		$link = wp_get_attachment_url($attachment->ID);
		$thumbnail_link = wp_get_attachment_thumb_url($attachment->ID);

		if( ! $thumbnail_link ){
			$thumbnail_link = "";
		}

		if( is_numeric($attachment->post_parent) ){
			if( gettype($attachment->post_parent) == "integer" ){
				$parent_id = $attachment->post_parent;
			}else{
				$parent_id = intval($attachment->post_parent);
			}
		}else{
			$parent_id = 0;
		}

		if( ! $thumbnail_link ){
			$thumbnail_link = "";
		}

		if( is_numeric($attachment->ID) ){
			if( gettype($attachment->ID) == "integer" ){
				$attachment_id = $attachment->ID;
			}else{
				$attachment_id = intval($attachment->ID);
			}
		}else{
			$attachment_id = 0;
		}

		if( ! $metadata = wp_get_attachment_metadata($attachment_id) ){
			$metadata = array(
				'width'			=> "",
				'height'		=> "" ,
				'hwstring_small'=> "" ,
				'file'			=> "" ,
				'sizes'			=> array('medium' => array('height' => "", 'width' => "", 'file' => ""), 
										 'thumbnail' => array('height' => "", 'width' => "", 'file' => "")) ,
				'image_meta'	=> ""
			);
		}

		if( isset($metadata['sizes']) == FALSE  || $metadata['sizes'] == '' ){
			$metadata['sizes'] = array('medium' => array('height' => "", 'width' => "", 'file' => ""), 
										 'thumbnail' => array('height' => "", 'width' => "", 'file' => ""));
		}else{
			 if( array_key_exists("medium", $metadata['sizes']) == FALSE ){
				$metadata['sizes']['medium'] = array('height' => "", 'width' => "", 'file' => "");
			 }
			 if( array_key_exists("thumbnail", $metadata['sizes']) == FALSE ){
				$metadata['sizes']['thumbnail'] = array('height' => "", 'width' => "", 'file' => "");
			 }
		}
		
		$attachment_struct = array(
			'date_created_gmt'		=> new IXR_Date($attachment_date_gmt),
			'parent'				=> $parent_id ,
			'link'					=> $link,
			'thumbnail'				=> $thumbnail_link,
			'title'					=> $attachment->post_title,
			'caption'				=> $attachment->post_excerpt,
			'description'			=> $attachment->post_content,
			'metadata'				=> $metadata,
			'attachment_id'			=> $attachment_id,
		);

		return $attachment_struct;
	}

/* ------------------------------------------------------------------------- */
	function wpex_getMediaLibrary($args) {
		$raw_args = $args;
		$this->escape($args);

		$blog_id	= (int) $args[0];
		$username	= $args[1];
		$password	= $args[2];
		$struct		= isset( $args[3] ) ? $args[3] : array() ;

		if ( !$user = $this->login($username, $password) )
			return $this->error;

		if ( !current_user_can( 'upload_files' ) )
			return new IXR_Error( 401, __( 'Sorry, you cannot use MediaLibrary.' ) );

		do_action('xmlrpc_call', 'wp.getMediaLibrary');

		$parent_id = ( isset($struct['parent_id']) ) ? absint($struct['parent_id']) : '' ;
		$mime_type = ( isset($struct['mime_type']) ) ? $struct['mime_type'] : '' ;
		$offset = ( isset($struct['offset']) ) ? absint($struct['offset']) : 0 ;
		$number = ( isset($struct['number']) ) ? absint($struct['number']) : -1 ;

		$attachments = get_posts( array('post_type' => 'attachment', 'post_parent' => $parent_id, 'offset' => $offset, 'numberposts' => $number, 'post_mime_type' => $mime_type ) );
		$num_attachments = count($attachments);

		if ( ! $num_attachments )
			return array();

		$attachments_struct = array();
		$extensions = array("jpg", "jpeg", "gif", "png", "bmp", "tif", "tiff");

		foreach ($attachments as $attachment ){
			$attachments_struct[] = $this->wpex_getMediaItem( array( $raw_args[0], $raw_args[1], $raw_args[2], $attachment->ID ) );
		}
		
		return $attachments_struct;

	}

/* ------------------------------------------------------------------------- */
/* Search Media Item                                                         */
/* ------------------------------------------------------------------------- */

	function wpex_findMediaLibrary($args) {
		$raw_args = $args;
		$this->escape($args);

		$blog_id	= (int) $args[0];
		$username	= $args[1];
		$password	= $args[2];
		$struct		= isset( $args[3] ) ? $args[3] : array() ;
		$keyword	= isset( $args[4] ) ? $args[4] : '';
		$upload_date	= isset( $args[5] ) ? $args[5] : '';

		if ( !$user = $this->login($username, $password) )
			return $this->error;

		if ( !current_user_can( 'upload_files' ) )
			return new IXR_Error( 401, __( 'Sorry, you cannot upload files.' ) );

		do_action('xmlrpc_call', 'wp.getMediaLibrary');

		$parent_id = ( isset($struct['parent_id']) ) ? absint($struct['parent_id']) : '' ;
		$mime_type = ( isset($struct['mime_type']) ) ? $struct['mime_type'] : '' ;
		$offset = 0;
		$number = -1;

		$attachments = get_posts( array('post_type' => 'attachment', 'post_parent' => $parent_id, 'offset' => $offset, 'numberposts' => $number, 'post_mime_type' => $mime_type ) );
		$num_attachments = count($attachments);

		if ( ! $num_attachments )
			return array();

		$attachments_struct = array();
		$extensions = array("jpg", "jpeg", "gif", "png", "bmp", "tif", "tiff");

		foreach ($attachments as $attachment ){

			$findItem = true;

			if ( $keyword <> '' ){
				if ( stristr($attachment->post_title , $keyword) == false ){
					$findItem = false;
				}
			}
			
			if ( $upload_date <> '' ){
				$modifiedDate = date('Ymd',strtotime($attachment->post_modified_gmt));
				if ( stristr($modifiedDate , $upload_date) == false ){
					$findItem = false;
				}
			}
			
			if ( $findItem == true ){
				$attachments_struct[] = $this->wpex_getMediaItem( array( $raw_args[0], $raw_args[1], $raw_args[2], $attachment->ID ) );
			}
		}
		
		return $attachments_struct;

	}


/* ------------------------------------------------------------------------- */
/* Search Post                                                               */
/* ------------------------------------------------------------------------- */
	function wpex_findRecentPostTitles($args) {

		$this->escape($args);

		$blog_ID     = (int) $args[0];
		$username  = $args[1];
		$password   = $args[2];
		$keyword	= isset( $args[3] ) ? $args[3] : '';
		$category_keyword	= isset( $args[4] ) ? $args[4] : '';
		$tag_keyword	= isset( $args[5] ) ? $args[5] : '';
		$postdate	= isset( $args[6] ) ? $args[6] : '';


		$query = array( 'numberposts' => -1 );

		if ( !$user = $this->login($username, $password) )
			return $this->error;

		do_action('xmlrpc_call', 'mt.getRecentPostTitles');

		$posts_list = wp_get_recent_posts( $query );

		if ( !$posts_list ) {
			$this->error = new IXR_Error(500, __('Either there are no posts, or something went wrong.'));
			return $this->error;
		}

		foreach ($posts_list as $entry) {

			$findPost = true;

			if ( $keyword <> '' ){
				if ( stristr($entry['post_title'], $keyword) == false ){
					$findPost = false;
				}
			}
			
			if ( $category_keyword <> '' ){
				$catids = wp_get_post_categories($entry['ID']);
				$find_item = false;
				if ( !empty( $catids ) ) {
					foreach ( $catids as $ctg ){
						if ( stristr(get_cat_name ($ctg), $category_keyword) <> false ){
							$find_item = true;
							break;
						}
					}
				}
				$findPost = $find_item;
			}

			if ( $tag_keyword <> '' ){
				$tags = wp_get_post_tags( $entry['ID'] );
				$find_item = false;
				if ( !empty( $tags ) ) {
					foreach ( $tags as $tg ){
						if ( stristr($tg->name, $tag_keyword) <> false ){
							$find_item = true;
							break;
						}
					}
				}
				$findPost = $find_item;
			}
			
			if ( $postdate <> '' ){
/*				$postedDate = date('Ymd',strtotime($entry['post_date_gmt']));	*/
				$postedDate = date('Ymd',strtotime($entry['post_date']));
				if ( stristr($postedDate , $postdate) == false ){
					$findPost = false;
				}
			}

			if ( $findPost == true ){

				if ( !current_user_can( 'edit_post', $entry['ID'] ) )
					continue;

				$post_date = mysql2date('Ymd\TH:i:s', $entry['post_date'], false);
				$post_date_gmt = mysql2date('Ymd\TH:i:s', $entry['post_date_gmt'], false);

				// For drafts use the GMT version of the date
				if ( $entry['post_status'] == 'draft' )
					$post_date_gmt = get_gmt_from_date( mysql2date( 'Y-m-d H:i:s', $entry['post_date'] ), 'Ymd\TH:i:s' );

				// Get comment count this post
				do_action('xmlrpc_call', 'wp.getCommentCount');
				$count = wp_count_comments( (int) $entry['ID'] );
				
				$struct[] = array(
					'dateCreated' => new IXR_Date($post_date),
					'userid' => $entry['post_author'],
					'postid' => (string) $entry['ID'],
					'title' => $entry['post_title'],
					'post_status' => $entry['post_status'],
					'date_created_gmt' => new IXR_Date($post_date_gmt),
					'wpex_total_comments' => $count->total_comments
				);

			}
		}

		$recent_posts = array();
		for ( $j=0; $j<count($struct); $j++ ) {
			array_push($recent_posts, $struct[$j]);
		}

		return $recent_posts;
	}

/* ------------------------------------------------------------------------- */
/* Replace string by the Post */
/* ------------------------------------------------------------------------- */
	function wpex_replaceString($args) {

		global $wpdb;
		
		$this->escape($args);

		$blog_ID     = (int) $args[0];
		$username  = $args[1];
		$password   = $args[2];
		$beforeString	= isset( $args[3] ) ? $args[3] : '';
		$afterString	= isset( $args[4] ) ? $args[4] : '';
		$dateFrom	= isset( $args[5] ) ? $args[5] : '';
		$dateTo	= isset( $args[6] ) ? $args[6] : '';

		$mode	= isset( $args[7] ) ? $args[7] : '';

		$type	= isset( $args[8] ) ? $args[8] : '';

		if( get_magic_quotes_gpc() ) {
			$beforeString = stripslashes("$beforeString");
		}

if ( !$user = $this->login($username, $password) )
			return $this->error;

	
		$result = array();

		if ( $dateFrom <> '' && dateTo <> '' ){
			$all_date = false;
		}else{
			$all_date = true;
		}


		if ( $type == 'POST' ){

			do_action('xmlrpc_call', 'mt.getRecentPostTitles');
			$query = array( 'numberposts' => -1 );
			$posts_list = wp_get_recent_posts( $query );

			if ( !$posts_list ) {
				$this->error = new IXR_Error(500, __('Either there are no posts, or something went wrong.'));
				return $this->error;
			}
			foreach ($posts_list as $entry) {

				// Post date
				//$post_date = $entry['post_date'];
				$post_date = mysql2date('Ymd', $entry['post_date'], false);
				$disp_post_date = mysql2date('Y/m/d H:i:s', $entry['post_date'], false);
				if ( $all_date == true ){
						$search = True;
				}else{
					if ( $dateFrom <= $post_date and $post_date <= $dateTo ){
						$search = True;
					}else{
						$search = false;
					}
				}
				
				if ( $search == True ){

					// ****** if ( stristr($entry['post_content'], $beforeString) != false ){
					if ( preg_match("/" . preg_quote($beforeString,'/') . "/i", $entry['post_content']) ){
						if ( $mode == 'R' ){

							// Contents
					        $content = $wpdb->get_var("SELECT post_content FROM {$wpdb->posts} WHERE ID = '{$entry['ID']}' LIMIT 1");

							// Replace
							$replaced_content = preg_replace("/" . preg_quote($beforeString,'/') . "/i", $afterString, $content);

							// Update the post
							$wpdb->query("UPDATE {$wpdb->posts} SET post_content = '{$replaced_content}' WHERE ID = '{$entry['ID']}'");

						}

						$struct[] = array(
							'dateCreated' => $disp_post_date,
							'postid' => (string) $entry['ID'],
							'title' => $entry['post_title']
						);
					}
				}

			}
		}
		
		if ( $type == 'PAGE' ){

			do_action('xmlrpc_call', 'wp.getPages');
			$pages = get_posts( array('post_type' => 'page', 'post_status' => 'any', 'numberposts' => -1) );
			$num_pages = count($pages);

			if ( !$pages ) {
				$this->error = new IXR_Error(500, __('Either there are no posts, or something went wrong.'));
				return $this->error;
			}

			// If we have pages, put together their info.
			if ( $num_pages >= 1 ) {
				$pages_struct = array();

				foreach ($pages as $page) {
					if ( current_user_can( 'edit_page', $page->ID ) )
						$pages_struct[] = $this->_prepare_page( $page );
				}
			}

			foreach ($pages_struct as $page) {

				// Post date
				// $post_date = $page['dateCreated'];

				// ****** if ( stristr($page['description'], $beforeString) != false ){
				if ( preg_match("/" . preg_quote($beforeString,'/') . "/i", $entry['description']) ){

					if ( $mode == 'R' ){

						// Contents
				        $content = $page['description'];

						// Replace
						$replaced_content = preg_replace("/" . preg_quote($beforeString,'/') . "/i", $afterString, $content);

						// Update the post
						$wpdb->query("UPDATE {$wpdb->posts} SET post_content = '{$replaced_content}' WHERE ID = '{$page['page_id']}'");

					}

					$struct[] = array(
						'dateCreated' =>  '',
						'postid' => (string) $page['page_id'],
						'title' => $page['title']
					);
				}

			}
		}

		$result = array();
		for ( $j=0; $j<count($struct); $j++ ) {
			array_push($result, $struct[$j]);
		}
		
		return $result;
	}

	function MyEscape( $str ) {
		
	}

/* ------------------------------------------------------------------------- */
/* Get Pages */
/* ------------------------------------------------------------------------- */
	function wpex_getPages($args) {

		$this->escape($args);

		$blog_id	= (int) $args[0];
		$username	= $args[1];
		$password	= $args[2];
		$num_pages	= isset($args[3]) ? (int) $args[3] : 10;

		if ( !$user = $this->login($username, $password) )
			return $this->error;

		if ( !current_user_can( 'edit_pages' ) )
			return new IXR_Error( 401, __( 'Sorry, you cannot edit pages.' ) );

		do_action('xmlrpc_call', 'wp.getPages');

		$pages = get_posts( array('post_type' => 'page', 'post_status' => 'any', 'numberposts' => $num_pages) );
		$num_pages = count($pages);

		// If we have pages, put together their info.
		if ( $num_pages >= 1 ) {
			$pages_struct = array();

			foreach ($pages as $page) {
				if ( current_user_can( 'edit_page', $page->ID ) )

					$post_date = mysql2date('Ymd\TH:i:s', $page['post_date'], false);
					$pages_struct[] = array(
						'dateCreated' => new IXR_Date($post_date),
						'title' => $page->post_title,
						'userid' => $page->post_author,
						'page_id' => $page->ID,
						'page_status' => $page->post_status
					);

			}

			return($pages_struct);
		}
		// If no pages were found return an error.
		else {
			return(array());
		}
	}

/* ------------------------------------------------------------------------- */
/* Save Custom fields for WordPessPost                                       */
/* ------------------------------------------------------------------------- */
	function wpxe_save_custom_fields($args){

		$this->escape($args);

		$blog_id	= (int) $args[0];
		$username	= $args[1];
		$password	= $args[2];
		$post_id	= isset($args[3]) ? $args[3] : '';
		$wpxe_custom_fields	= $args[4];

		if ( $post_id <> '' ){
			foreach($wpxe_custom_fields as $wpxe_field) {

				$wpxe_value = get_post_meta($post_id, $wpxe_field['key']);
				$wpex_set_value = $wpxe_field['value'];
		 		
				if( $wpxe_value == "" && $wpex_set_value!="" ) {
					add_post_meta($post_id, $wpxe_field['key'], $wpex_set_value, true);
				} elseif ( $wpxe_value != $wpex_set_value && $wpex_set_value<>"" ) {
					update_post_meta($post_id, $wpxe_field['key'], $wpex_set_value);
				} elseif ( $wpex_set_value == "" ) {
					delete_post_meta( $post_id, $wpxe_field['key'] );
				}
			}
			return true;

		}else{
			return false;
		}
	}


}


?>